from __future__ import annotations

from django import forms


class MessageForm(forms.Form):
    """Form for posting a new chat message with an optional file attachment."""

    content = forms.CharField(
        widget=forms.Textarea(
            attrs={
                "rows": 2,
                "placeholder": "Type a message...",
                "class": "anyllm-input",
            }
        ),
        required=False,
    )
    file = forms.FileField(
        widget=forms.FileInput(attrs={"class": "anyllm-file-input"}),
        required=False,
    )
