# Generated by Django 5.2.14 on 2026-05-16 17:20

import django_anyllm.models
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_anyllm", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="chat",
            name="model",
            field=models.CharField(
                default=django_anyllm.models._default_model, max_length=100
            ),
        ),
        migrations.AlterField(
            model_name="chat",
            name="provider",
            field=models.CharField(
                blank=True,
                default=django_anyllm.models._default_provider,
                max_length=100,
            ),
        ),
    ]
