from django.apps import AppConfig


class AnyLLMConfig(AppConfig):
    """Django app configuration for django-anyllm."""

    name = "django_anyllm"
    default_auto_field = "django.db.models.BigAutoField"
    verbose_name = "Any LLM"
