from django.urls import path

from django_anyllm.views import (
    ChatCreateView,
    ChatDeleteView,
    ChatDetailView,
    ChatListView,
    ChatStreamView,
    MessageCreateView,
)

app_name = "django_anyllm"

urlpatterns = [
    path("", ChatListView.as_view(), name="chat_list"),
    path("create/", ChatCreateView.as_view(), name="chat_create"),
    path("<int:pk>/delete/", ChatDeleteView.as_view(), name="chat_delete"),
    path("<int:pk>/", ChatDetailView.as_view(), name="chat_detail"),
    path("<int:pk>/messages/", MessageCreateView.as_view(), name="message_create"),
    path("<int:pk>/stream/", ChatStreamView.as_view(), name="chat_stream"),
]
